@@ -146,6 +146,38 @@ static const char *xpm_del[] = {
 };
 
 
+static const char *all_vis_xpm[] = {
+"12 9 3 1",
+" 	c None",
+"@	c #6EA5D7",
+"+	c #000000",
+"            ",
+"    ++++    ",
+"  ++@@@@++  ",
+" +@@@++@@@+ ",
+"+@@@++++@@@+",
+" +@@@++@@@+ ",
+"  ++@@@@++  ",
+"    ++++    ",
+"            ",
+};
+
+static const char *all_invis_xpm[] = {
+"12 9 3 1",
+" 	c None",
+"@	c #6EA5D7",
+"+	c #000000",
+" @+@        ",
+"  @+@+++    ",
+"  +@+@@@++  ",
+" +@@@+@@@@+ ",
+"+@@@+@+@@@@+",
+" +@@@+@+@@+ ",
+"  ++@@@@+@  ",
+"    ++++@+@ ",
+"         @+@",
+};
+
 
 typedef struct {
 	char buf[32][20];
@@ -167,7 +199,7 @@ struct layersel_ctx_s {
 	rnd_hid_dad_subdialog_t sub;
 	camv_design_t *camv;
 	int sub_inited;
-	int wbut_up, wbut_down, wbut_top, wbut_bottom, wbut_load, wbut_remove;
+	int wbut_up, wbut_down, wbut_top, wbut_bottom, wbut_load, wbut_remove, wbut_vis, wbut_invis;
 	int lock_vis, lock_sel;
 	int selected; /* layer idx (lid) of the currently selected layer */
 	vtp0_t layers; /* -> ls_layer_t */
@@ -251,6 +283,8 @@ static void layer_button_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 	else if (wid == ls->wbut_bottom) rnd_actionl("Layer", "bottom", NULL);
 	else if (wid == ls->wbut_load)   { rnd_actionl("Load", "Layer", NULL) || rnd_actionva(&camv.hidlib, "Zoom", "auto_first", NULL); }
 	else if (wid == ls->wbut_remove) rnd_actionl("Layer", "del", NULL);
+	else if (wid == ls->wbut_vis)    rnd_actionl("Layer", "all-visible", NULL);
+	else if (wid == ls->wbut_invis)  rnd_actionl("Layer", "all-invisible", NULL);
 	else rnd_message(RND_MSG_ERROR, "Internal error: layer_button_cb(): invalid wid\n");
 }
 
@@ -378,6 +412,16 @@ static void layersel_docked_create(layersel_ctx_t *ls, camv_design_t *camv)
 				RND_DAD_CHANGE_CB(ls->sub.dlg, layer_button_cb);
 				RND_DAD_SET_ATTR_FIELD(ls->sub.dlg, user_data, ls);
 				ls->wbut_remove = RND_DAD_CURRENT(ls->sub.dlg);
+			RND_DAD_PICBUTTON(ls->sub.dlg, all_vis_xpm);
+				RND_DAD_HELP(ls->sub.dlg, "all layers visible");
+				RND_DAD_CHANGE_CB(ls->sub.dlg, layer_button_cb);
+				RND_DAD_SET_ATTR_FIELD(ls->sub.dlg, user_data, ls);
+				ls->wbut_vis = RND_DAD_CURRENT(ls->sub.dlg);
+			RND_DAD_PICBUTTON(ls->sub.dlg, all_invis_xpm);
+				RND_DAD_HELP(ls->sub.dlg, "all layers invisible\nexcept for the current layer group");
+				RND_DAD_CHANGE_CB(ls->sub.dlg, layer_button_cb);
+				RND_DAD_SET_ATTR_FIELD(ls->sub.dlg, user_data, ls);
+				ls->wbut_invis = RND_DAD_CURRENT(ls->sub.dlg);
 			RND_DAD_BEGIN_HBOX(ls->sub.dlg);
 				RND_DAD_COMPFLAG(ls->sub.dlg, RND_HATF_EXPFILL);
 			RND_DAD_END(ls->sub.dlg);
@@ -473,6 +517,16 @@ static void layer_del_all(void)
 	camv_hid_redraw(layersel.camv);
 }
 
+static void all_vis(camv_design_t *camv, int vis)
+{
+	long lid;
+
+	for(lid = 0; lid < camv->layers.used; lid++)
+		camv_layer_set_vis(camv, lid, vis, 1);
+
+	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYERS_CHANGED, NULL);
+	camv_hid_redraw(layersel.camv);
+}
 
 const char camv_acts_Layer[] = "Layer([up|down|top|bottom|del])";
 const char camv_acth_Layer[] = "Move or remove the current layer\n";
@@ -510,6 +564,12 @@ fgw_error_t camv_act_Layer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		if (layersel.selected < 0) goto nolayer;
 		layer_del();
 	}
+	else if (strcmp(cmd, "all-visible") == 0) {
+		all_vis(camv, 1);
+	}
+	else if (strcmp(cmd, "all-invisible") == 0) {
+		all_vis(camv, 0);
+	}
 	else if (rnd_strcasecmp(cmd, "delall") == 0) {
 		if (layersel.selected < 0) goto nolayer;
 		layer_del_all();
